@@ -57,14 +57,14 @@ class ChecksBuildTest(unittest.TestCase):
         env = create_env()
         pkg = create_manifest("mock", build_depends=[ "other_catkin" ])
 
-        result = mock_lint(env, pkg, 
+        result = mock_lint(env, pkg,
             """
             find_package(catkin REQUIRED COMPONENTS other_catkin)
             """,
         checks=cc.depends)
         self.assertEqual([ "ORDER_VIOLATION" ], result)
 
-        result = mock_lint(env, pkg, 
+        result = mock_lint(env, pkg,
             """
             project(mock)
             catkin_package()
@@ -73,7 +73,7 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.depends)
         self.assertEqual([ "ORDER_VIOLATION" ], result)
 
-        result = mock_lint(env, pkg, 
+        result = mock_lint(env, pkg,
             """
             project(mock)
             find_package(catkin COMPONENTS other_catkin)
@@ -81,7 +81,15 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.depends)
         self.assertEqual([ "MISSING_REQUIRED" ], result)
 
-        result = mock_lint(env, pkg, 
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED other_catkin)
+            """,
+        checks=cc.depends)
+        self.assertEqual([ "MISSING_COMPONENTS", "UNCONFIGURED_BUILD_DEPEND" ], result)
+
+        result = mock_lint(env, pkg,
             """
             project(mock)
             find_package(catkin REQUIRED COMPONENTS other_catkin)
@@ -90,10 +98,10 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.depends)
         self.assertEqual([ "DUPLICATE_FIND" ], result)
 
-        result = mock_lint(env, pkg, 
+        result = mock_lint(env, pkg,
             """
             project(mock)
-            find_package(other_catkin)
+            find_package(other_catkin REQUIRED)
             find_package(catkin REQUIRED COMPONENTS other_catkin)
             """,
         checks=cc.depends)
@@ -103,7 +111,7 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED COMPONENTS other_system)
-            find_package(other_catkin)
+            find_package(other_catkin REQUIRED)
             """,
         checks=cc.depends)
         self.assertEqual([ "NO_CATKIN_COMPONENT", "MISSING_DEPEND" ], result)
@@ -116,6 +124,25 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.depends)
         self.assertEqual([ "UNCONFIGURED_BUILD_DEPEND" ], result)
 
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED)
+            find_package(other_catkin)
+            """,
+        checks=cc.depends)
+        self.assertEqual([ "MISSING_REQUIRED" ], result)
+
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED)
+            find_package(other_catkin)
+            if(other_catkin_FOUND)
+            endif()
+            """,
+        checks=cc.depends)
+        self.assertEqual([], result)
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/src/mock.cpp"))
     def do_targets(self):
@@ -230,6 +257,8 @@ class ChecksBuildTest(unittest.TestCase):
             include_directories(include)
             catkin_package(INCLUDE_DIRS include)
             add_executable(mock src/mock.cpp)
+            add_executable(test_mock src/mock.cpp)
+            add_executable(mock_example src/mock.cpp)
             install(PROGRAMS bin/script DESTINATION ${CATKIN_PACKAGE_BIN_DESTINATION})
             install(FILES share/file DESTINATION ${CATKIN_PACKAGE_SHARE_DESTINATION})
             install(TARGETS mock RUNTIME DESTINATION ${CATKIN_PACKAGE_BIN_DESTINATION})
@@ -294,7 +323,7 @@ class ChecksBuildTest(unittest.TestCase):
 
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/src/mock.cpp"))
-    @patch("os.path.isdir", lambda x: x == os.path.normpath("/mock-path/include"))
+    @patch("os.path.isdir", lambda x: x in [ os.path.normpath("/mock-path/include"), os.path.normpath("/mock-path/include/mock") ])
     def do_exports(self):
         env = create_env()
         pkg = create_manifest("mock", build_depends=[ "other_catkin", "other_system" ], run_depends=[ "other_catkin", "other_system" ])
@@ -302,14 +331,15 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
-            find_package(other_system)
+            find_package(other_catkin REQUIRED)
+            find_package(other_system REQUIRED)
             catkin_package(
             INCLUDE_DIRS include
             CATKIN_DEPENDS other_catkin
             DEPENDS other_system
             LIBRARIES mock
             )
+            include_directories(include)
             add_library(mock src/mock.cpp)
             """,
         checks=cc.exports)
@@ -319,8 +349,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
-            find_package(other_system)
+            find_package(other_catkin REQUIRED)
+            find_package(other_system REQUIRED)
             catkin_package(
             INCLUDE_DIRS ${CMAKE_CURRENT_BINARY_DIR}
             CATKIN_DEPENDS other_catkin
@@ -334,7 +364,7 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED COMPONENTS other_catkin)
-            find_package(other_system)
+            find_package(other_system REQUIRED)
             find_path(Stuff_INCLUDE_DIRS stuff.h)
             find_library(Stuff_LIBRARIES stuff)
             catkin_package(
@@ -349,8 +379,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
-            find_package(other_system)
+            find_package(other_catkin REQUIRED)
+            find_package(other_system REQUIRED)
             catkin_package(
             INCLUDE_DIRS missing_include
             CATKIN_DEPENDS other_catkin
@@ -364,8 +394,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
-            find_package(other_system)
+            find_package(other_catkin REQUIRED)
+            find_package(other_system REQUIRED)
             catkin_package(
             DEPENDS other_catkin other_system
             )
@@ -377,8 +407,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
-            find_package(other_system)
+            find_package(other_catkin REQUIRED)
+            find_package(other_system REQUIRED)
             catkin_package(
             CATKIN_DEPENDS other_catkin other_system
             )
@@ -390,7 +420,7 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
+            find_package(other_catkin REQUIRED)
             catkin_package(
             CATKIN_DEPENDS other_catkin
             DEPENDS other_system
@@ -403,7 +433,7 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
+            find_package(other_catkin REQUIRED)
             catkin_package(
             CATKIN_DEPENDS other_catkin
             INCLUDE_DIRS /not/in/package
@@ -422,6 +452,16 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.exports)
         self.assertEqual([ "MISSING_DEPEND" ], result)
 
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED)
+            pkg_check_modules(FOO foo)
+            catkin_package(DEPENDS FOO)
+            """,
+        checks=cc.exports)
+        self.assertEqual([ "EXPORTED_PKG_CONFIG"], result)
+
         pkg = create_manifest("mock", build_depends=[ "other_msgs" ], run_depends=[ "other_msgs"])
         result = mock_lint(env, pkg,
             """
@@ -469,6 +509,27 @@ class ChecksBuildTest(unittest.TestCase):
         checks=cc.exports)
         self.assertEqual([ "EXPORT_LIB_NOT_LIB" ], result)
 
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED)
+            catkin_package(INCLUDE_DIRS include)
+            add_executable(test_mock src/mock.cpp)
+            """,
+        checks=cc.exports)
+        self.assertEqual([ "MISSING_BUILD_INCLUDE" ], result)
+
+        result = mock_lint(env, pkg,
+            """
+            project(mock)
+            find_package(catkin REQUIRED)
+            catkin_package(INCLUDE_DIRS include)
+            include_directories(include/${PROJECT_NAME})
+            add_executable(test_mock src/mock.cpp)
+            """,
+        checks=cc.exports)
+        self.assertEqual([ "MISSING_BUILD_INCLUDE", "AMBIGUOUS_BUILD_INCLUDE" ], result)
+
 
     @patch("os.path.isfile", lambda x: x == os.path.normpath("/mock-path/config.xml"))
     def do_plugins(self):
@@ -516,8 +577,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
@@ -529,8 +590,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             generate_messages(DEPENDENCIES other_catkin)
             add_message_files(FILES mock.msg)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
@@ -542,8 +603,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
@@ -554,8 +615,8 @@ class ChecksBuildTest(unittest.TestCase):
         result = mock_lint(env, pkg,
             """
             project(mock)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             find_package(catkin REQUIRED)
@@ -568,8 +629,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             catkin_package(CATKIN_DEPENDS message_runtime)
@@ -581,8 +642,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
             """,
@@ -593,8 +654,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             generate_messages(DEPENDENCIES other_catkin)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
             """,
@@ -605,8 +666,8 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(message_generation)
-            find_package(other_catkin)
+            find_package(message_generation REQUIRED)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             catkin_package(CATKIN_DEPENDS other_catkin)
@@ -632,7 +693,7 @@ class ChecksBuildTest(unittest.TestCase):
             """
             project(mock)
             find_package(catkin REQUIRED)
-            find_package(other_catkin)
+            find_package(other_catkin REQUIRED)
             add_message_files(FILES mock.msg)
             generate_messages(DEPENDENCIES other_catkin)
             catkin_package(CATKIN_DEPENDS other_catkin message_runtime)
